import S3 from './S3'

export const getFileSrc = (file, call) => {
  let reader = new FileReader()
  // 新建 FileReader 对象
  reader.onload = function () {
    // 当 FileReader 读取文件时候，读取的结果会放在 FileReader.result 属性中
    call(this.result)
  }
  // 设置以什么方式读取文件，这里以base64方式
  reader.readAsDataURL(file)
}

// 获取文件的base64  尺寸 宽高等信息
export const resetFile = (file, call) => {
  let reader = new FileReader()
  // 新建 FileReader 对象
  reader.onload = function () {
    const src = this.result
    // 当 FileReader 读取文件时候，读取的结果会放在 FileReader.result 属性中
    const img = new Image()
    img.setAttribute('crossOrigin', 'Anonymous')
    img.src = src
    img.onload = () => {
      call({
        src,
        width: img.width,
        height: img.height,
        size: file.size,
        name: file.name,
        type: file.type,
        dpi: 0
      })
    }
  }
  // 设置以什么方式读取文件，这里以base64方式
  reader.readAsDataURL(file)
}

// 获取文件的base64  尺寸 宽高等信息
export const resetCdnFile = (src, call) => {
  const img = new Image()
  img.setAttribute('crossOrigin', 'Anonymous')
  img.src = src
  img.onload = () => {
    var xhr = new XMLHttpRequest()
    xhr.open('HEAD', src, true)
    xhr.onreadystatechange = function () {
      if (xhr.readyState == 4) {
        let size = 0
        if (xhr.status == 200) {
          size = xhr.getResponseHeader('Content-Length')
        }
        let name = src.split('/')
        name = name[name.length - 1]
        call({
          src,
          width: img.width,
          height: img.height,
          size: Number(size),
          name,
          type: 'image/png',
          dpi: 0
        })
      }
    }
    xhr.send(null)
  }
}

// 格式化文件大小
export const formatBytes = function (bytes, decimals) {
  const k = 1024, dm = decimals || 2,
    sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'],
    i = Math.floor(Math.log(bytes) / Math.log(k))
  return bytes ? parseFloat((bytes / Math.pow(k, i)).toFixed(dm)) + ' ' + sizes[i] : '0 Bytes'
}

/**
 * 单文件上传
 * @param file  文件对象
 * @param payload  {
 *   // 上传进度
 *   onProgress: Function(progressData)
 *  }
 * @returns Promise
 */
export function FileUpload (file, payload) {
  return S3.putObject(file, Object.assign({
    onProgress: undefined
  }, payload))
}
// 内容生成
export function FileResourceUpload (file, payload) {
  return S3.putObject(file, Object.assign({
    onProgress: undefined
  }, payload))
}

/**
 * 秒转化时分秒
 */
export const getTime = function (time) {
  // 转换为式分秒
  let h = parseInt(time / 60 / 60 % 24)
  h = h < 10 ? '0' + h : h
  let m = parseInt(time / 60 % 60)
  m = m < 10 ? '0' + m : m
  let s = parseInt(time % 60)
  s = s < 10 ? '0' + s : s
  return `${h}:${m}:${s}`
}
/**
 * 秒转分秒
 */
export const getM = function (time) {
  let m = parseInt(time / 60 % 60)
  m = m < 10 ? '0' + m : m
  let s = parseInt(time % 60)
  s = s < 10 ? '0' + s : s
  return m + '`' + s + '``'
}
/**
 * 时间戳转日期格式
 */
export const timestampToTime = function (timestamp) {
  const date = new Date(timestamp)
  const Y = date.getFullYear() + '-'
  const M =
    (date.getMonth() + 1 < 10
      ? '0' + (date.getMonth() + 1)
      : date.getMonth() + 1) + '-'
  const D = (date.getDate() < 10 ? '0' + date.getDate() : date.getDate()) + ' '
  const h = date.getHours() + ':'
  const m = date.getMinutes()
  // const s = date.getSeconds()
  return Y + M + D + h + m
}
export const formateDate1 = function (time, fmt = 'YYYY-MM-dd hh:mm') {
  let date = new Date(time)
  if (/(y+)/.test(fmt)) {
    fmt = fmt.replace(RegExp.$1, (date.getFullYear() + '').substr(4 - RegExp.$1.length))
  }
  let o = {
    'Y+': date.getFullYear(),
    'M+': date.getMonth() + 1,
    'd+': date.getDate(),
    'h+': date.getHours(),
    'm+': date.getMinutes(),
    's+': date.getSeconds()
  }
  for (let k in o) {
    if (new RegExp(`(${k})`).test(fmt)) {
      let str = o[k] + ''
      fmt = fmt.replace(RegExp.$1, (RegExp.$1.length === 1) ? str : padLeftZero(str))
    }
  }
  return fmt
}
// 左边补0函数
function padLeftZero (str) {
  return ('00' + str).substr(str.length)
}
export const formateDate = function (value) { // 时间戳转换日期格式方法
  if (value == null) {
    return ''
  } else {
    const date = new Date(value)
    const y = date.getFullYear() // 年
    let MM = date.getMonth() + 1 // 月
    MM = MM < 10 ? ('0' + MM) : MM
    let d = date.getDate() // 日
    d = d < 10 ? ('0' + d) : d
    let h = date.getHours() // 时
    h = h < 10 ? ('0' + h) : h
    let m = date.getMinutes()// 分
    m = m < 10 ? ('0' + m) : m
    let s = date.getSeconds()// 秒
    s = s < 10 ? ('0' + s) : s
    return y + '-' + MM + '-' + d + ' ' + h + ':' + m
  }
}
